import 'package:healthrian_ble_interface/healthrian_ble_interface.dart';

class UUIDBuiltin {
  static const Map<Characteristics, String> builtinMap = {
    Characteristics.CONFIG_ECG: '00002902-0000-1000-8000-00805f9b34fb',
    Characteristics.MEASUREMENT_ECG: '00002a37-0000-1000-8000-00805f9b34fb',
    Characteristics.TAP_BUTTON: '00002a38-0000-1000-8000-00805f9b34fb',
    Characteristics.CONTROL_POINT: '00002a39-0000-1000-8000-00805f9b34fb',
    Characteristics.BATTERY_LEVEL: '00002a19-0000-1000-8000-00805F9B34FB',
  };
}

class UUID {
  UUID({
    Map<Enum, String> characteristicStringMap = UUIDBuiltin.builtinMap,
    this.enableEcg = true,
    this.enableOxi = false,
  }) {
    for (final e in characteristicStringMap.entries) {
      characteristic[e.key] = e.value;
    }
    final checkList = [
      /// ECG
      if (enableEcg) ...[
        Characteristics.START_ECG,
        Characteristics.STOP_ECG,
        Characteristics.PAUSE_ECG,
        Characteristics.SET_ECG,
      ],

      /// OXI
      if (enableOxi) ...[
        Characteristics.START_OXI,
        Characteristics.STOP_OXI,
        Characteristics.PAUSE_OXI,
        Characteristics.SET_OXI,
      ],

      /// DATA
      Characteristics.SET_DATA,
    ];
    for (final c in checkList) {
      if (characteristic[c] == null) {
        characteristic[c] = characteristic[Characteristics.CONTROL_POINT];
      }
    }
  }

  final characteristic = <Enum, String?>{
    for (final e in Characteristics.values) e: null,
  };

  final bool enableEcg;
  final bool enableOxi;
}
